@@ -27,9 +27,8 @@
 #include <MailTransportAkonadi/SentBehaviourAttribute>
 #include <MailTransportAkonadi/TransportAttribute>
 
-#include <QtCore/QDateTime>
-#include <QtCore/QString>
-#include <QtCore/QStringList>
+#include <QString>
+#include <QStringList>
 
 #include <KCompositeJob>
 
@@ -145,7 +144,7 @@ public:
       Creates the item and places it in the outbox.
       It is now queued for sending by the mail dispatcher agent.
     */
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
 
 protected Q_SLOTS:
     /**
@@ -153,14 +152,12 @@ protected Q_SLOTS:
 
       (reimplemented from KCompositeJob)
     */
-    void slotResult(KJob *) Q_DECL_OVERRIDE;
+    void slotResult(KJob *) override;
 
 private:
     class Private;
     friend class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void outboxRequestResult(KJob *))
 };
 } // namespace MailTransport
 
